@@ -5,7 +5,7 @@ import (
 	"fmt"
 )
 
-func getFilenameOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
+func getFilenameOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode) (Context, error) {
 	log.Debugf("GetFilename")
 
 	var results = list.New()
@@ -19,7 +19,7 @@ func getFilenameOperator(d *dataTreeNavigator, context Context, expressionNode *
 	return context.ChildContext(results), nil
 }
 
-func getFileIndexOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
+func getFileIndexOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode) (Context, error) {
 	log.Debugf("GetFileIndex")
 
 	var results = list.New()
